@@ -29,7 +29,9 @@ import (
 	"github.com/spf13/viper"
 	"github.com/tonistiigi/units"
 
-	"github.com/tensorchord/envd/pkg/docker"
+	"github.com/tensorchord/envd/pkg/driver"
+	"github.com/tensorchord/envd/pkg/driver/docker"
+	"github.com/tensorchord/envd/pkg/driver/nerdctl"
 	"github.com/tensorchord/envd/pkg/flag"
 	"github.com/tensorchord/envd/pkg/types"
 )
@@ -112,41 +114,31 @@ func (c generalClient) Close() error {
 // that can be used to connect to it.
 func (c *generalClient) maybeStart(ctx context.Context,
 	runningTimeout, connectingTimeout time.Duration) (string, error) {
-	if c.driver == types.BuilderTypeDocker {
-		dockerClient, err := docker.NewClient(ctx)
+	var client driver.Client
+	var err error
+	switch c.driver {
+	case types.BuilderTypeDocker:
+		client, err = docker.NewClient(ctx)
 		if err != nil {
 			return "", err
 		}
-
-		created, err := dockerClient.Exists(ctx, c.containerName)
+	case types.BuilderTypeNerdctl:
+		client, err = nerdctl.NewClient(ctx)
 		if err != nil {
 			return "", err
 		}
-
-		if !created {
-			c.logger.Debug("container not created, creating...")
-			if _, err := dockerClient.StartBuildkitd(
-				ctx, c.image, c.containerName, c.mirror); err != nil {
-				return "", err
-			}
-			if err := dockerClient.WaitUntilRunning(
-				ctx, c.containerName, runningTimeout); err != nil {
-				return "", err
-			}
-		}
-		running, _ := dockerClient.IsRunning(ctx, c.containerName)
-		if created && !running {
-			c.logger.Warnf("start the created contrainer %s", c.containerName)
-			_, err := dockerClient.StartBuildkitd(ctx, c.image, c.containerName, c.mirror)
-			if err != nil {
-				c.logger.Warnf("please remove or restart the container %s", c.containerName)
-				return "", errors.Errorf("container %s is stopped", c.containerName)
-			}
-		}
-
-		c.logger.Debugf("container is running, check if it's ready at %s...", c.BuildkitdAddr())
+	default:
 	}
 
+	if client != nil {
+		if _, err := client.StartBuildkitd(ctx,
+			c.image, c.containerName, c.mirror, runningTimeout); err != nil {
+			return "", err
+		}
+	}
+
+	c.logger.Debugf("container is running, check if it's ready at %s...", c.BuildkitdAddr())
+
 	if err := c.waitUntilConnected(ctx, connectingTimeout); err != nil {
 		return "", errors.Wrapf(err,
 			"failed to connect to buildkitd %s", c.BuildkitdAddr())
