@@ -72,13 +72,32 @@ func (e dockerEngine) ListImage(ctx context.Context) ([]types.EnvdImage, error)
 	for _, img := range images {
 		envdImg, err := types.NewImageFromSummary(img)
 		if err != nil {
-			return nil, errors.Wrap(err, "failed to create envd image from the docker image")
+			return nil, errors.Wrapf(err, "failed to create envd image `%s` from the docker image", img.ID)
 		}
 		envdImgs = append(envdImgs, *envdImg)
 	}
 	return envdImgs, nil
 }
 
+func (e dockerEngine) GetEnvironment(ctx context.Context, env string) (*types.EnvdEnvironment, error) {
+	ctrs, err := e.ContainerList(ctx, dockertypes.ContainerListOptions{
+		Filters: dockerFiltersWithName(env),
+	})
+	if err != nil {
+		return nil, errors.Wrapf(err, "failed to get container: %s", env)
+	}
+
+	if len(ctrs) <= 0 {
+		return nil, errors.Newf("can not find the container: %s", env)
+	}
+
+	environment, err := types.NewEnvironmentFromContainer(ctrs[0])
+	if err != nil {
+		return nil, errors.Wrap(err, "failed to create env from the container")
+	}
+	return environment, nil
+}
+
 func (e dockerEngine) ListEnvironment(
 	ctx context.Context) ([]types.EnvdEnvironment, error) {
 	ctrs, err := e.ContainerList(ctx, dockertypes.ContainerListOptions{
@@ -168,6 +187,24 @@ func (e dockerEngine) ListImageDependency(ctx context.Context, image string) (*t
 	return dep, nil
 }
 
+func (e dockerEngine) ListEnvRuntimeGraph(ctx context.Context, env string) (*ir.RuntimeGraph, error) {
+	ctr, err := e.ContainerInspect(ctx, env)
+	if err != nil {
+		return nil, errors.Wrapf(err, "failed to inspect container: %s", env)
+	}
+	code, ok := ctr.Config.Labels[types.RuntimeGraphCode]
+	if !ok {
+		return nil, errors.Newf("failed to get runtime graph label from container: %s", env)
+	}
+	logrus.WithField("env", env).Debugf("runtime graph: %s", code)
+	rg := ir.RuntimeGraph{}
+	err = rg.Load([]byte(code))
+	if err != nil {
+		return nil, errors.Wrapf(err, "failed to create runtime graph from the container: %s", env)
+	}
+	return &rg, err
+}
+
 // ListEnvDependency gets the dependencies of the given environment.
 func (e dockerEngine) ListEnvDependency(
 	ctx context.Context, env string) (*types.Dependency, error) {
@@ -365,6 +402,11 @@ func (e dockerEngine) StartEnvd(ctx context.Context, so StartOptions) (*StartRes
 		RestartPolicy: rp,
 	}
 
+	// shared memory size
+	if so.ShmSize > 0 {
+		hostConfig.ShmSize = int64(so.ShmSize) * 1024 * 1024
+	}
+
 	// Configure ssh port.
 	natPort := nat.Port(fmt.Sprintf("%d/tcp", envdconfig.SSHPortInContainer))
 	hostConfig.PortBindings[natPort] = []nat.PortBinding{
@@ -489,6 +531,18 @@ func (e dockerEngine) StartEnvd(ctx context.Context, so StartOptions) (*StartRes
 
 func (e dockerEngine) Destroy(ctx context.Context, name string) (string, error) {
 	logger := logrus.WithField("container", name)
+
+	ctr, err := e.ContainerInspect(ctx, name)
+	if err != nil {
+		errCause := errors.UnwrapAll(err).Error()
+		if strings.Contains(errCause, "No such container") {
+			// If the container is not found, it is already destroyed or the name is wrong.
+			logger.Infof("cannot find container %s, maybe it's already destroyed or the name is wrong", name)
+			return "", nil
+		}
+		return "", errors.Wrap(err, "failed to inspect the container")
+	}
+
 	// Refer to https://docs.docker.com/engine/reference/commandline/container_kill/
 	if err := e.ContainerKill(ctx, name, "KILL"); err != nil {
 		errCause := errors.UnwrapAll(err).Error()
@@ -509,40 +563,14 @@ func (e dockerEngine) Destroy(ctx context.Context, name string) (string, error)
 		return "", errors.Wrap(err, "failed to remove the container")
 	}
 
-	// remove image
-	tags, err := e.getContainerTag(ctx, name)
-	if err != nil {
-		return "", errors.Wrap(err, "failed to get the container tags")
-	} else {
-		for _, tag := range tags {
-			if _, err := e.ImageRemove(ctx, tag, dockertypes.ImageRemoveOptions{}); err != nil {
-				return "", errors.Errorf("remove image %s failed: %w", tag, err)
-			}
-			logrus.Infof("image(%s) is destroyed", tag)
-		}
+	if _, err := e.ImageRemove(ctx, ctr.Image, dockertypes.ImageRemoveOptions{}); err != nil {
+		return "", errors.Errorf("remove image %s failed: %w", ctr.Image, err)
 	}
+	logrus.Infof("image(%s) is destroyed", ctr.Image)
 
 	return name, nil
 }
 
-func (e dockerEngine) getContainerTag(ctx context.Context, name string) ([]string, error) {
-	tags := []string{}
-	// check the images instead of running containers because `envd build` also produce images
-	images, err := e.ListImage(ctx)
-	if err != nil {
-		return tags, err
-	}
-	for _, img := range images {
-		if strings.HasPrefix(img.Name, fmt.Sprintf("%s:", name)) {
-			tags = append(tags, img.Name)
-		}
-	}
-	if len(tags) == 0 {
-		logrus.Infof("cannot find the image of %s", name)
-	}
-	return tags, nil
-}
-
 func (e dockerEngine) WaitUntilRunning(ctx context.Context,
 	name string, timeout time.Duration) error {
 	logger := logrus.WithField("container", name)
