@@ -20,16 +20,19 @@ const (
 	ContainerLabelRStudioServerAddr = "ai.tensorchord.envd.rstudio.server.address"
 	ContainerLabelSSHPort           = "ai.tensorchord.envd.ssh.port"
 
-	ImageLabelVendor    = "ai.tensorchord.envd.vendor"
-	ImageLabelGPU       = "ai.tensorchord.envd.gpu"
-	ImageLabelAPT       = "ai.tensorchord.envd.apt.packages"
-	ImageLabelPyPI      = "ai.tensorchord.envd.pypi.packages"
-	ImageLabelR         = "ai.tensorchord.envd.r.packages"
-	ImageLabelCUDA      = "ai.tensorchord.envd.gpu.cuda"
-	ImageLabelCUDNN     = "ai.tensorchord.envd.gpu.cudnn"
-	ImageLabelContext   = "ai.tensorchord.envd.build.context"
-	ImageLabelCacheHash = "ai.tensorchord.envd.build.digest"
-	RuntimeGraphCode    = "ai.tensorchord.envd.runtimeGraph"
+	ImageLabelContainerName = "ai.tensorchord.envd.container.name"
+	ImageLabelVendor        = "ai.tensorchord.envd.vendor"
+	ImageLabelGPU           = "ai.tensorchord.envd.gpu"
+	ImageLabelRepo          = "ai.tensorchord.envd.repo"
+	ImageLabelPorts         = "ai.tensorchord.envd.ports"
+	ImageLabelAPT           = "ai.tensorchord.envd.apt.packages"
+	ImageLabelPyPI          = "ai.tensorchord.envd.pypi.commands"
+	ImageLabelR             = "ai.tensorchord.envd.r.packages"
+	ImageLabelCUDA          = "ai.tensorchord.envd.gpu.cuda"
+	ImageLabelCUDNN         = "ai.tensorchord.envd.gpu.cudnn"
+	ImageLabelContext       = "ai.tensorchord.envd.build.context"
+	ImageLabelCacheHash     = "ai.tensorchord.envd.build.digest"
+	RuntimeGraphCode        = "ai.tensorchord.envd.runtimeGraph"
 
 	ImageVendorEnvd = "envd"
 )
